Cabric
==================

.. image:: https://pypip.in/v/fabez/badge.svg
    :target: https://pypi.python.org/pypi/fabez/
.. image:: https://pypip.in/d/fabez/badge.svg
    :target: https://pypi.python.org/pypi/fabez/
.. image:: https://pypip.in/license/fabez/badge.svg
    :target: https://pypi.python.org/pypi/fabez/

A deploy tool for Centos, based on Fabric.


FAQ
----------------------------
`Chinese Version <https://github.com/baixing/cabric/blob/master/docs/faq.rst>`_


Release Note
----------------------------


* 0.8.x
    * support supervisor
    * support statsd
    * support send release-note use mail
    * support smtp server
    * support php
    * support more config type
    * improve install python lxml
    * support tengine
    * support nginx
    * support python3,pypy
    * support python complex package.e.g:pillow
    * support redis
    * support mongodb
    * support mysql
    * core feature
        * add user
        * git clone/git pull code
        * upload private | public key
        * ...





